import { getTranslations, getLocale } from 'next-intl/server';
import Link from 'next/link';
import React from 'react';
import { Metadata } from 'next';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faFacebook, faTwitter } from '@fortawesome/free-brands-svg-icons';

interface PostCategory {
  name: string;
}

interface Post {
  id: number;
  title: {
    rendered: string;
  };
  content: {
    rendered: string;
  };
  thumbnail_full_url: string;
  thumbnail_article_1x: string;
  thumbnail_article_2x: string;
  post_categories: PostCategory[];
  acf: {
    time_to_read: string;
    title?: string;
    description?: string;
    og_image?: string;
    og_type?: string;
    header_image?: {
      sizes: {
        article_header_image_1x: string;
        article_header_image_2x: string;
      };
    };
  };
  slug: string;
  link: string;
}

export async function generateMetadata({
  params,
}: {
  params: Promise<{ slug: string }>
}): Promise<Metadata> {
  const { slug } = await params;
  const locale = await getLocale();
  
  try {
    const data = await fetch(`https://w.mssg.me/${locale}/wp-json/wp/v2/posts?slug=${slug}`);
    const post: Post[] = await data.json();
    const pData = post[0];

    if (!pData) {
      return {
        title: 'Post not found',
        description: 'The requested blog post could not be found.'
      };
    }

    const openGraphUrl = `https://mssg.me/${locale}/blog/${slug}`;
    
    return {
      title: pData.acf.title || pData.title.rendered,
      description: pData.acf.description,
      openGraph: {
        siteName: 'mssg.me',
        title: pData.acf.title || pData.title.rendered,
        description: pData.acf.description,
        url: openGraphUrl,
        type: (pData.acf.og_type as 'website' | 'article') || 'article',
        images: pData.acf.og_image ? [
          {
            url: pData.acf.og_image,
            alt: pData.title.rendered,
          }
        ] : undefined,
      },
      twitter: {
        card: 'summary',
        title: pData.acf.title || pData.title.rendered,
        description: pData.acf.description,
        images: pData.acf.og_image ? [pData.acf.og_image] : undefined,
      },
    };
  } catch (error) {
    console.error('Error generating metadata:', error);
    return {
      title: 'Blog Post',
      description: 'Read our latest blog post on mssg.me'
    };
  }
}

export default async function Page({
  params,
}: {
  params: Promise<{ slug: string }>
}) {
  const { slug } = await params;
  const locale = await getLocale();
  const t = await getTranslations({ locale });
  const postsData = await fetch(`https://w.mssg.me/${locale}/wp-json/wp/v2/posts`);
  const posts: Post[] = await postsData.json();
  const data = await fetch(`https://w.mssg.me/${locale}/wp-json/wp/v2/posts?slug=${slug}`);
  const post: Post[] = await data.json();
  const pData = post[0];

  return (
    <div className="page-wrapper">
        <main>
            <section className="section-article">
                <div className="common-content">
                    <div className="section-article-content">
                        <div className="section-article-header">
                            <div className="section-article-header-img">
                                <img 
                                    src={pData.acf.header_image ? pData.acf.header_image.sizes.article_header_image_1x : pData.thumbnail_full_url}
                                    srcSet={[pData.acf.header_image ? pData.acf.header_image.sizes.article_header_image_1x : `${pData.thumbnail_full_url} 1x`, pData.acf.header_image ? pData.acf.header_image.sizes.article_header_image_2x : `${pData.thumbnail_full_url} 2x`].join(', ')}
                                    alt={pData.title.rendered}
                                />
                            </div>
                            <div className="section-article-header-heading">
                                <div className="section-article-header-heading-content">
                                    <h1>{pData.title.rendered}</h1>
                                    <span>
                                        {pData.post_categories.map((cat: PostCategory, index: number) => (
                                          <React.Fragment key={index}>
                                            <span>{cat.name}</span> | {pData.acf.time_to_read}
                                          </React.Fragment>
                                        ))}
                                    </span>
                                </div>
                            </div>
                        </div>
                        <div className="section-article-text clearfix" dangerouslySetInnerHTML={{ __html: pData.content.rendered }} />
                        <ul className="article-share-list">
                            <li className="article-share-list-fb">
                                <a href={`https://www.facebook.com/sharer/sharer.php?u=https://www.mssg.me/${locale}/blog/${slug}`} target="_blank" data-share-social="Facebook" className="article-share-link">
                                    <FontAwesomeIcon icon={faFacebook} />
                                    Facebook
                                </a>
                            </li>
                            <li className="article-share-list-twitter">
                                <a href={`https://twitter.com/home?status=https://www.mssg.me/${locale}/blog/${slug}`} target="_blank" data-share-social="Twitter" className="article-share-link">
                                    <FontAwesomeIcon icon={faTwitter} />
                                    Twitter
                                </a>
                            </li>
                        </ul>
                    </div>
                </div>
            </section>
            <section className="section-fp-news">
                <div className="common-content">
                    <div className="section-fp-news-content section-fp-news-content-article">
                        <h3>{t('single_article.posts_section.heading')}</h3>
                        <ul className="section-fp-news-list">
                            {posts.filter((post: Post) => post.id !== pData.id).slice(0,3).map((element: Post, index: number) => (
                              <li key={index}>
                                  <div className="section-fp-news-list-item-preview">
                                      <img 
                                          src={element.thumbnail_article_1x}
                                          srcSet={`${element.thumbnail_article_1x} 1x ` + `${element.thumbnail_article_2x} 2x`}
                                          alt={element.title.rendered}
                                      />
                                  </div>
                                  <div className="section-fp-news-list-item-content">
                                      <h4>{element.title.rendered}</h4>
                                      <span>
                                          {element.post_categories.map((cat: PostCategory, index: number) => (
                                            <React.Fragment key={index}>
                                              <span>{cat.name}</span> | {element.acf.time_to_read}
                                            </React.Fragment>
                                          ))}
                                      </span>
                                  </div>
                                  <Link href={`/blog/${element.slug}`} className="section-fp-news-list-item-link" />
                              </li>
                            ))}
                        </ul>
                    </div>
                </div>
            </section>
        </main>
    </div>
  );
}
