import { NextIntlClientProvider, hasLocale } from 'next-intl';
import { getTranslations } from 'next-intl/server';
import { notFound } from 'next/navigation';
import { routing } from '@/i18n/routing';
import { Inter } from "next/font/google";
import Template from './template';
import Header from './Header';
import Footer from './Footer';
import MainScripts from '@/app/ui/components/MainScripts';
import { GoogleTagManagerHead, GoogleTagManagerBody } from '@/app/ui/components/GoogleTagManager';

import '@/app/ui/wppages/css/index.css';
import '@/lib/fontawesome';

const interSans = Inter({
  variable: "--font-inter-sans",
  subsets: ["latin", "cyrillic"],
});

export async function generateMetadata({ params }: { params: Promise<{ locale: string }> }) {
  const { locale } = await params;
  const t = await getTranslations({ locale, namespace: 'website_home' });
  
  // Get the base URL from environment variables
  const protocol = process.env.PROTOCOL || 'https';
  const hostname = process.env.HOSTNAME || 'www.mssg.me';
  const baseUrl = `${protocol}://${hostname}`;
  
  // Current page path (this is for the root page, adjust for specific pages)
  const currentPath = '';
  
  // Generate canonical URL
  const canonicalUrl = locale === 'en' 
    ? `${baseUrl}${currentPath}`
    : `${baseUrl}/${locale}${currentPath}`;
  
  // Generate alternate URLs for all locales
  const alternateUrls: Record<string, string> = {};
  routing.locales.forEach((loc) => {
    alternateUrls[loc] = loc === 'en' 
      ? `${baseUrl}${currentPath}`
      : `${baseUrl}/${loc}${currentPath}`;
  });
  
  // Add x-default for users who don't match any specific language
  alternateUrls['x-default'] = `${baseUrl}${currentPath}`;
 
  return {
    title: t('head.title'),
    description: t('head.description'),
    alternates: {
      canonical: canonicalUrl,
      languages: alternateUrls,
    },
    icons: {
      other: [
        {
          rel: 'mask-icon',
          url: '/favicons/safari-pinned-tab.svg',
          color: '#000000',
        }
      ]
    }
  };
}

export default async function LocaleLayout({
  children,
  params
}: {
  children: React.ReactNode;
  params: Promise<{locale: string}>;
}) {
  const {locale} = await params;
  if (!hasLocale(routing.locales, locale)) {
    notFound();
  }
 
  return (
    <html lang={locale} id="homepage">
      <head>
        <GoogleTagManagerHead gtmId="GTM-5MPBB4D" />
      </head>
      <body className={interSans.variable}>
        <GoogleTagManagerBody gtmId="GTM-5MPBB4D" />
        <Template>
          <NextIntlClientProvider>
            <Header />
            {children}
            <Footer />
            <MainScripts />
          </NextIntlClientProvider>
        </Template>
      </body>
    </html>
  );
}
