import type { MetadataRoute } from 'next'
import { LOCALES, DEFAULT_LOCALE } from '../i18n/i18n'

interface BlogPost {
  slug: string;
  modified: string;
}

interface WordPressPost {
  slug: string;
  modified: string;
}

async function getBlogPosts(): Promise<BlogPost[]> {
  try {
    const response = await fetch(`https://w.mssg.me/${DEFAULT_LOCALE}/wp-json/wp/v2/posts?per_page=100`);
    if (!response.ok) return [];
    const posts = await response.json() as WordPressPost[];
    return posts.map((post: WordPressPost) => ({
      slug: post.slug,
      modified: post.modified
    }));
  } catch (error) {
    console.error('Failed to fetch blog posts:', error);
    return [];
  }
}

export default async function sitemap(): Promise<MetadataRoute.Sitemap> {
  const baseUrl = 'https://mssg.me';
  const staticPages = ['', '/blog', '/faq-next', '/privacy-policy', '/terms-of-use'];
  const sitemap: MetadataRoute.Sitemap = [];

  // Add static pages for all locales
  for (const page of staticPages) {
    for (const locale of LOCALES) {
      const url = locale === DEFAULT_LOCALE 
        ? `${baseUrl}${page}`
        : `${baseUrl}/${locale}${page}`;
      
      sitemap.push({
        url,
        lastModified: new Date(),
        changeFrequency: page === '' ? 'monthly' : 'weekly',
        priority: page === '' ? 1.0 : (page === '/blog' ? 0.8 : 0.5),
        alternates: {
          languages: Object.fromEntries(
            LOCALES.map(loc => [
              loc,
              loc === DEFAULT_LOCALE 
                ? `${baseUrl}${page}`
                : `${baseUrl}/${loc}${page}`
            ])
          )
        }
      });
    }
  }

  // Add blog posts for all locales
  const blogPosts = await getBlogPosts();
  for (const post of blogPosts) {
    for (const locale of LOCALES) {
      const url = locale === DEFAULT_LOCALE 
        ? `${baseUrl}/blog/${post.slug}`
        : `${baseUrl}/${locale}/blog/${post.slug}`;
      
      sitemap.push({
        url,
        lastModified: new Date(post.modified),
        changeFrequency: 'monthly',
        priority: 0.6,
        alternates: {
          languages: Object.fromEntries(
            LOCALES.map(loc => [
              loc,
              loc === DEFAULT_LOCALE 
                ? `${baseUrl}/blog/${post.slug}`
                : `${baseUrl}/${loc}/blog/${post.slug}`
            ])
          )
        }
      });
    }
  }

  return sitemap;
}
